# Copyright (C) 2021-2023 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
from typing import Any

from .resourceaction import ResourceAction


class CollectionAction(ResourceAction):
    __module__: str = 'cbra.core.resource'

    def is_detail(self) -> bool:
        return False

    def get_return_annotation(self) -> Any:
        return self.endpoint.model.__list_model__


# Copyright (C) 2022 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
from typing import Callable
from typing import Protocol


class IVerifier(Protocol):

    async def verify(
        self,
        signature: bytes,
        message: bytes,
        encoder: Callable[[bytes], bytes] = lambda x: x
    ) -> bool:
        ...


# Copyright (C) 2023 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
from typing import Literal

import pydantic

from cbra.ext import secrets


class ClientSecret(pydantic.BaseModel):
    kind: Literal['ClientSecret']
    client_id: str
    client_secret: str | dict[str, str]

    async def get_secret(self) -> str:
        secret = self.client_secret
        if isinstance(secret, dict):
            container = await secrets.load(secrets.parse(**secret))
            secret = container.get_value()
        return secret